@@ -94,8 +94,8 @@ pub struct FlatpakModule {
     pub cmake: Option<bool>,
 
     /// Build system to use.
-    #[serde(deserialize_with = "crate::build_system::deserialize_from_string")]
-    #[serde(serialize_with = "crate::build_system::serialize_to_string")]
+    #[serde(deserialize_with = "crate::build_system::FlatpakBuildSystem::deserialize")]
+    #[serde(serialize_with = "crate::build_system::FlatpakBuildSystem::serialize")]
     #[serde(skip_serializing_if = "Option::is_none")]
     pub buildsystem: Option<FlatpakBuildSystem>,
 
@@ -574,6 +574,33 @@ pub struct FlatpakBuildOptions {
 mod tests {
     use super::*;
 
+    #[test]
+    pub fn test_parse_build_options() {
+        let module_manifest = r###"
+            name: "flatpak-rs"
+            buildsystem: simple
+            cleanup: [ "*" ]
+            build-options:
+               cflags: "-O2 -g"
+               cxxflags: "-O2 -g"
+               env:
+                   V: "1"
+               arch:
+                   x86_64:
+                       cflags: "-O3 -g"
+            config-opts: []
+            sources:
+              -
+                "shared-modules/linux-audio/lv2.json"
+        "###;
+        match FlatpakModule::parse(FlatpakManifestFormat::YAML, module_manifest) {
+            Err(e) => std::panic::panic_any(e),
+            Ok(module) => {
+                assert_eq!(module.name, "flatpak-rs");
+            }
+        }
+    }
+
     #[test]
     pub fn test_parse_extra_data() {
         let module_manifest = r###"
